package main

import (
	"flag"
	"os"
	"os/signal"
	"syscall"

	"go-common/app/job/live/wallet/conf"
	"go-common/app/job/live/wallet/service"
	"go-common/library/log"
)

func main() {
	flag.Parse()
	if err := conf.Init(); err != nil {
		log.Error("conf.Init() error(%v)", err)
		panic(err)
	}
	// init log
	log.Init(conf.Conf.Log)
	defer log.Close()
	log.Info("/live-wallet start")
	// service init
	srv := Service.New(conf.Conf)
	// init pprof conf.Conf.Perf
	// init signal
	c := make(chan os.Signal, 1)
	signal.Notify(c, syscall.SIGHUP, syscall.SIGQUIT, syscall.SIGTERM, syscall.SIGINT)
	for {
		s := <-c
		log.Info("/live-wallet get a signal %s", s.String())
		switch s {
		case syscall.SIGQUIT, syscall.SIGTERM, syscall.SIGINT:
			log.Info("/live-wallet exit")
			srv.Close()
			return
		case syscall.SIGHUP:
		default:
			return
		}
	}
}
